@@ -34,17 +34,20 @@ from .element_h1 import ElementH1
 from .element_vector_h1 import ElementVectorH1
 from .element_hdiv import ElementHdiv
 from .element_hcurl import ElementHcurl
-from .element_tri import ElementTriP1, ElementTriP2, ElementTriDG,\
-    ElementTriP0, ElementTriRT0, ElementTriMorley,\
-    ElementTriArgyris, ElementTriMini
-from .element_quad import ElementQuad0, ElementQuad1, ElementQuad2,\
-    ElementQuadS2, ElementQuadDG, ElementQuadP,\
-    ElementQuadBFS
-from .element_tet import ElementTetP0, ElementTetP1, ElementTetP2,\
-    ElementTetRT0, ElementTetN0, ElementTetMini
+from .element_tri import (ElementTriP1, ElementTriP2, ElementTriDG,
+                          ElementTriP0, ElementTriRT0, ElementTriMorley,
+                          ElementTriArgyris, ElementTriMini, ElementTriCR,
+                          ElementTriHermite)
+from .element_quad import (ElementQuad0, ElementQuad1, ElementQuad2,
+                           ElementQuadS2, ElementQuadDG, ElementQuadP,
+                           ElementQuadBFS)
+from .element_tet import (ElementTetP0, ElementTetP1, ElementTetP2,
+                          ElementTetRT0, ElementTetN0, ElementTetMini,
+                          ElementTetCR)
 from .element_hex import ElementHex1, ElementHex2, ElementHexS2  # noqa
-from .element_line import ElementLineP1, ElementLineP2,\
-    ElementLinePp, ElementLineHermite, ElementLineMini  # noqa
+from .element_line import (ElementLineP1, ElementLineP2,
+                           ElementLinePp, ElementLineHermite,
+                           ElementLineMini)  # noqa
 from .element_composite import ElementComposite  # noqa
 
 
@@ -59,10 +62,12 @@ __all__ = [
     "ElementTriP2",
     "ElementTriDG",
     "ElementTriP0",
+    "ElementTriCR",
     "ElementTriRT0",
     "ElementTriMorley",
     "ElementTriArgyris",
     "ElementTriMini",
+    "ElementTriHermite",
     "ElementQuad0",
     "ElementQuad1",
     "ElementQuad2",
@@ -76,6 +81,7 @@ __all__ = [
     "ElementTetRT0",
     "ElementTetN0",
     "ElementTetMini",
+    "ElementTetCR",
     "ElementHex1",
     "ElementHex2",
     "ElementHexS2",
