@@ -5,11 +5,12 @@ from ...mesh.mesh_line import MeshLine
 
 
 class ElementLineMini(ElementH1):
+
     nodal_dofs = 1
     interior_dofs = 1
     dim = 1
     maxdeg = 1 + dim
-    dofnames = ['u']
+    dofnames = ['u', 'NA']
     doflocs = np.array([[0.],
                         [1.],
                         [np.nan] * dim])
