@@ -5,11 +5,12 @@ from ...mesh.mesh2d import MeshTri
 
 
 class ElementTriMini(ElementH1):
+
     nodal_dofs = 1
     interior_dofs = 1
     dim = 2
     maxdeg = 1 + dim
-    dofnames = ['u']
+    dofnames = ['u', 'NA']
     doflocs = np.array([[0., 0.],
                         [1., 0.],
                         [0., 1.],
