@@ -1,12 +1,13 @@
 """Import mesh from JSON as defined by :class:`skfem.mesh.to_dict`."""
 
 import json
+from typing import Type
 
-from skfem.mesh import MeshLine, MeshTri, MeshQuad,\
-    MeshTet, MeshHex, Mesh
+from skfem.mesh import (MeshLine, MeshTri, MeshQuad,
+                        MeshTet, MeshHex, Mesh)
 
 
-def from_file(filename: str):
+def from_file(filename: str) -> Mesh:
     with open(filename, 'r') as handle:
         d = json.load(handle)
 
@@ -14,6 +15,8 @@ def from_file(filename: str):
     dim = len(d['p'][0])
     nverts = len(d['t'][0])
 
+    mesh_type: Type = Mesh
+
     if dim == 1:
         mesh_type = MeshLine
     elif dim == 2 and nverts == 3:
@@ -32,4 +35,4 @@ def from_file(filename: str):
 
 def to_file(mesh: Mesh, filename: str):
     with open(filename, 'w') as handle:
-        _ = json.dump(mesh.to_dict(), handle)
+        json.dump(mesh.to_dict(), handle)
