@@ -4,7 +4,7 @@ from typing import Optional, Type, Dict
 import numpy as np
 from numpy import ndarray
 
-from .mesh2d import Mesh2D, MeshType
+from .mesh2d import Mesh2D
 from .mesh_tri import MeshTri
 
 
@@ -88,9 +88,9 @@ class MeshQuad(Mesh2D):
         self._build_mappings()
 
     @classmethod
-    def init_tensor(cls: Type[MeshType],
+    def init_tensor(cls: Type,
                     x: ndarray,
-                    y: ndarray) -> MeshType:
+                    y: ndarray) -> Mesh2D:
         """Initialize a tensor product mesh.
 
         The mesh topology is as follows::
@@ -134,7 +134,7 @@ class MeshQuad(Mesh2D):
         return cls(p, t.astype(np.int64))
 
     @classmethod
-    def init_refdom(cls: Type[MeshType]) -> MeshType:
+    def init_refdom(cls: Type) -> Mesh2D:
         """Initialize a mesh that includes only the reference quad.
 
         The mesh topology is as follows::
@@ -150,7 +150,9 @@ class MeshQuad(Mesh2D):
             O-------------*
 
         """
-        return cls()
+        p = np.array([[0., 0.], [1., 0.], [1., 1.], [0., 1.]]).T
+        t = np.array([[0, 1, 2, 3]]).T
+        return cls(p, t)
 
     def _build_mappings(self):
         # do not sort since order defines counterclockwise order
@@ -299,7 +301,7 @@ class MeshQuad(Mesh2D):
         from skfem.element import ElementQuad1, ElementLineP1
         return MappingIsoparametric(self, ElementQuad1(), ElementLineP1())
 
-    def element_finder(self):
+    def element_finder(self, mapping=None):
         tri_finder = self._splitquads().element_finder()
 
         def finder(*args):
