@@ -4,7 +4,6 @@ import numpy as np
 from numpy import ndarray
 
 from .mesh3d import Mesh3D
-from ..mesh import MeshType
 
 
 class MeshHex(Mesh3D):
@@ -100,15 +99,15 @@ class MeshHex(Mesh3D):
         self._build_mappings()
 
     @classmethod
-    def init_refdom(cls: Type[MeshType]):
+    def init_refdom(cls: Type) -> Mesh3D:
         """Initialise a mesh of the reference domain."""
         return cls()
 
     @classmethod
-    def init_tensor(cls: Type[MeshType],
+    def init_tensor(cls: Type,
                     x: ndarray,
                     y: ndarray,
-                    z: ndarray) -> MeshType:
+                    z: ndarray) -> Mesh3D:
         """Initialise a tensor product mesh.
 
         Parameters
@@ -322,7 +321,8 @@ class MeshHex(Mesh3D):
     def save(self,
              filename: str,
              point_data: Optional[Dict[str, ndarray]] = None,
-             cell_data: Optional[Dict[str, ndarray]] = None):
+             cell_data: Optional[Dict[str, ndarray]] = None,
+             **kwargs):
         """Export the mesh and fields using meshio. (Hexahedron version.)
 
         Parameters
