@@ -1,3 +1,3 @@
 """Legacy location for skfem.helpers."""
 
-from skfem.helpers import *
+from skfem.helpers import *  # noqa
